//C ja C++ kirjastot
#include <cstdlib>
#include <iostream>
#include <string>
#include <sstream>

//FMod
#include "fmod/fmod.h"

//SDL kirjastot
#include <SDL.h>
#include <SDL_ttf.h>

//Omat headerit
#include "config_file/config_file.h"
#include "valikko/valikko.h"
#include "valikko/asetusvalikko.h"
#include "peli/peli.h"
#include "common/common.h"
#include "peli/hiscores.h"

using namespace std;

enum textquality {solid, shaded, blended};

//Funktioiden esittelyt
int alusta_SDL(SDL_Surface *naytto, asetukset conffi);
asetukset haeAsetukset();

void PiirraKuva(SDL_Surface *kuva, SDL_Surface *naytto, int x, int y);
void blitText(TTF_Font *fontti, SDL_Surface **destSurf, SDL_Color fgColor, SDL_Color bgColor, char teksti[], textquality quality);
TTF_Font* LoadFont(char *filename, int ptsize);

int main ( int argc, char** argv )
{
    /////////////////////////////////////////////////////////////////////// Muuttuja esittelyt
    //SDL
    SDL_Surface *otsikko;
    SDL_Surface *valikko_tausta; //Tähän ladataan valikon tausta
    SDL_Surface *valikko_tausta_2; //Tähän ladataan valikon syvyys > 0 kuva
    SDL_Surface *peli_nimi;

    SDL_Surface *buf;
    SDL_Surface *buf2;
    SDL_Surface *buf3;
    SDL_Surface *naytto;

    SDL_Event tapahtuma; //Näppäinpainalluksia varten
    Uint32 flagit; //Flagit joita SDL_SetVideoMode ottaa

    TTF_Font *fontti;
    TTF_Font *fontti_sis;
    TTF_Font *nimi;
    SDL_Surface *tekstiPinta;
    SDL_Surface *tekstiPintaValittu;
    SDL_Surface *tekstiPinta2;
    SDL_Surface *tekstiPintaValittu2;

    char teksti[100];

    SDL_Color tekstiValkoinen = {255, 255, 255, 255};
    SDL_Color tekstiMusta = {0, 0, 0, 255};
    SDL_Color tekstiSininen = {70, 108, 178, 255};
    SDL_Color taustaVari = {0, 0, 0, 0};

    //OMAT
    int valikko_syvyys;
    asetukset conffi; //Asetukset pelille
    bool pois = false; //while silmukass käytettävä muuttuja
    bool peliin = false; //Haluttiinko peliin
    Peli peli; //Itse peli

    config_file kieli;

    valikko paavalikko;
    valikko tehnytvalikko;
    asetus_valikko asetusvalikko;

    //FMOD
    FMOD_SYSTEM *system; //FMOD systeemi

    FMOD_CHANNEL *channel_musiikki; //FMOD kanava musiikeille
    FMOD_CHANNEL *channel_musiikki_valikko; //FMOD kanava musiikeille
    FMOD_CHANNEL *channel; //FMOD kanava

    FMOD_SOUND *musiikki; //FMOD ääni
    FMOD_SOUND *musiikki_valikko; //FMOD ääni

    FMOD_SOUND *valikko; //FMOD ääni
    FMOD_SOUND *alku; //FMOD ääni

    ///////////////////////////////////////////////////////////////////////
    //OMAT ALUSTUS
    conffi = haeAsetukset(); //Haetaan asetukset

    kieli.lataa_tiedosto("media/language/suomi.txt");

    if (TTF_Init() == -1) {  //Alustetaan SDL-ttf. Jos ttf-initin paluuarvo on -1, jokin meni vikaan ja poistutaan.
        return 1;
    }

    fontti = LoadFont("media/fonts/normaali.ttf", 22);
    fontti_sis = LoadFont("media/fonts/normaali.ttf", 16);
    nimi = LoadFont("media/fonts/normaali.ttf", 44);

    valikko_syvyys = 0;
    valikko_tausta = IMG_Load("media/images/valikko_tausta.png");
    valikko_tausta_2 = IMG_Load("media/images/valikko.png");

    otsikko = IMG_Load("media/images/otsikko.png");

    //Pelin nimi
    sprintf(teksti, "IlmaNoxAir");
    blitText(nimi, &peli_nimi, tekstiMusta,taustaVari,teksti, blended);

    //SDL ALUSTUS
    alusta_SDL(naytto, conffi); //Alustetaan SDL

    flagit = SDL_DOUBLEBUF | SDL_HWSURFACE; //Peli käyttää kaksoispuskurointia, ettei välky
    //if (conffi.kokoruututila) //jos on true kokoruututila
        flagit = flagit | SDL_FULLSCREEN;

    naytto = SDL_SetVideoMode(conffi.resox, conffi.resoy, 32, flagit);

    SDL_FillRect(naytto, 0, SDL_MapRGB(naytto->format, 0, 0, 0));
    blitText(fontti, &tekstiPinta, tekstiValkoinen,taustaVari, "Ladataan...", blended);
    PiirraKuva(tekstiPinta, naytto, 400, 380);

    SDL_Flip(naytto);

    Uint32 rmask, gmask, bmask, amask;

    /* SDL interprets each pixel as a 32-bit number, so our masks must depend
       on the endianness (byte order) of the machine */
#if SDL_BYTEORDER == SDL_BIG_ENDIAN
    rmask = 0xff000000;
    gmask = 0x00ff0000;
    bmask = 0x0000ff00;
    amask = 0x000000ff;
#else
    rmask = 0x000000ff;
    gmask = 0x0000ff00;
    bmask = 0x00ff0000;
    amask = 0xff000000;
#endif

    buf = SDL_CreateRGBSurface(SDL_HWSURFACE, 1024, 768, 32,
                                   rmask, gmask, bmask, amask);

    buf2 = SDL_CreateRGBSurface(SDL_HWSURFACE, 1024, 768, 32,
                                   rmask, gmask, bmask, amask);

    buf3 = SDL_CreateRGBSurface(SDL_HWSURFACE, 1024, 768, 32,
                                   rmask, gmask, bmask, amask);

    PiirraKuva(valikko_tausta, buf, 0, 0);
    PiirraKuva(otsikko, buf, 0, 0);
    PiirraKuva(peli_nimi, buf, 250, -15);
    PiirraKuva(valikko_tausta_2, buf, 0, 0);

    PiirraKuva(valikko_tausta, buf2, 0, 0);
    PiirraKuva(otsikko, buf2, 0, 0);
    PiirraKuva(peli_nimi, buf2, 250, -15);
    PiirraKuva(valikko_tausta_2, buf2, 0, 0);

    PiirraKuva(valikko_tausta, buf3, 0, 0);
    PiirraKuva(otsikko, buf3, 0, 0);
    PiirraKuva(peli_nimi, buf3, 250, -15);
    PiirraKuva(valikko_tausta_2, buf3, 0, 0);

    //////////////////////////////////////////////////////////////////////////////////////////////////

    sprintf(teksti, "Ennatyslista");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    PiirraKuva(tekstiPinta, buf, 225, 200);


    hiscore hisc;

    vector<score> tull;
    vector<score>::iterator iter;

    tull = hisc.haeTulokset();

    iter = tull.begin();
    int i = 0;
    while (iter != tull.end()) {

        sprintf(teksti, (*iter).nimi.c_str());
        blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
        PiirraKuva(tekstiPinta, buf, 100, 30*i + 300);

        string t;
        ostringstream virta;
        virta << (*iter).pisteet;

        sprintf(teksti, virta.str().c_str());
        blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
        PiirraKuva(tekstiPinta, buf, 400, 30*i + 300);

        i++;
        iter++;
    }

    //Alustetaan valikot//////////////////////////////////////////////////////////////////////////////

    sprintf(teksti, (kieli.hae_str("Aloita_peli")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    paavalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 762, 232, 211, 67);
    PiirraKuva(tekstiPinta, buf, 762, 232);
    PiirraKuva(tekstiPinta, buf2, 762, 232);
    PiirraKuva(tekstiPinta, buf3, 762, 232);

    sprintf(teksti, (kieli.hae_str("Asetukset")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    paavalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 768, 350, 192, 67);
    PiirraKuva(tekstiPinta, buf, 768, 350);
    PiirraKuva(tekstiPinta, buf2, 768, 350);
    PiirraKuva(tekstiPinta, buf3, 768, 350);

    sprintf(teksti, (kieli.hae_str("Tehnyt")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    paavalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 806, 468, 122, 67);
    PiirraKuva(tekstiPinta, buf, 806, 468);
    PiirraKuva(tekstiPinta, buf2, 806, 468);
    PiirraKuva(tekstiPinta, buf3, 806, 468);

    sprintf(teksti, (kieli.hae_str("Lopeta_peli")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    paavalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 762, 590, 211, 67);
    PiirraKuva(tekstiPinta, buf, 762, 590);
    PiirraKuva(tekstiPinta, buf2, 762, 590);
    PiirraKuva(tekstiPinta, buf3, 762, 590);

    //////////////////////////ASETUKSET VALIKKO

    sprintf(teksti, (kieli.hae_str("On")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);

    sprintf(teksti, (kieli.hae_str("Ei")).c_str());
    blitText(fontti, &tekstiPinta2, tekstiMusta, taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu2, tekstiSininen, taustaVari,teksti, blended);

    asetusvalikko.asetaTosiJaEpatosi(tekstiPinta ,tekstiPinta2,tekstiPintaValittu,tekstiPintaValittu2);

    sprintf(teksti, (kieli.hae_str("Musiikki:")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    asetusvalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 114, 364, 160, 67, conffi.musiikki, 0, 0);
    PiirraKuva(tekstiPinta, buf3, 114, 364);

    sprintf(teksti, (kieli.hae_str("Aanet:")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    asetusvalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 132, 410, 119, 67, conffi.aanet, 0, 0);
    PiirraKuva(tekstiPinta, buf3, 132, 410);

    sprintf(teksti, (kieli.hae_str("Kokoruututila:")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    asetusvalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 58, 470, 275, 67, conffi.kokoruututila, 0,  0);
    PiirraKuva(tekstiPinta, buf3, 58, 470);

    sprintf(teksti, (kieli.hae_str("Peru")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    asetusvalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 8, 690, 121, 67, 0, 0, 0);
    PiirraKuva(tekstiPinta, buf3, 8, 690);

    sprintf(teksti, (kieli.hae_str("Tallenna_muutokset")).c_str());
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    blitText(fontti, &tekstiPintaValittu, tekstiSininen,taustaVari,teksti, blended);
    asetusvalikko.lisaaValinta(tekstiPinta, tekstiPintaValittu, 221, 690, 270, 67, 0, 0,  0);
    PiirraKuva(tekstiPinta, buf3, 221, 690);
    //////////////////////////

    sprintf(teksti, "Ohjelmoinut: Teijo Mursu");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 10, 200, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 10, 200);

    sprintf(teksti, "Suunnitellut: Teijo Mursu");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 10, 250, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 10, 250);

    sprintf(teksti, "Kuvat: Teijo Mursu");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 10, 350, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 10, 300);

    sprintf(teksti, "Pelimusiikki:");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 10, 300, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 10, 350);

    sprintf(teksti, "Yhtye:             Colored With Tophats");
    blitText(fontti_sis, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 40, 440, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 40, 400);

    sprintf(teksti, "Kappaleella: Raindrops On Stained Glass");
    blitText(fontti_sis, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 40, 462, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 40, 422);

    sprintf(teksti, "Valikkomusiikki:");
    blitText(fontti, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 10, 300, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 10, 450);

    sprintf(teksti, "Yhtye:             Daimfunk");
    blitText(fontti_sis, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 40, 440, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 40, 500);

    sprintf(teksti, "Kappaleella: Feed Up");
    blitText(fontti_sis, &tekstiPinta, tekstiMusta,taustaVari,teksti, blended);
    tehnytvalikko.lisaaValinta(tekstiPinta, tekstiPinta, 40, 462, 200, 67);
    PiirraKuva(tekstiPinta, buf2, 40, 522);

    //FMOD ALUSTUS///////////////////////////////////////////////////////////////////////////////////////////////////////////
    FMOD_System_Create(&system); //Luodaan systeemi
    FMOD_System_Init(system,100, FMOD_INIT_NORMAL, 0); //Ja alustetaan

    FMOD_System_CreateSound(system, "media/music/valikko.mp3", FMOD_DEFAULT, 0, &musiikki_valikko); //Ladataan ääni
    FMOD_Sound_SetLoopCount(musiikki_valikko, -1);

    FMOD_System_CreateSound(system, "media/music/peli.mp3", FMOD_DEFAULT, 0, &musiikki); //Ladataan ääni
    FMOD_Sound_SetLoopCount(musiikki, -1);

    FMOD_System_CreateSound(system, "media/sounds/valikko.mp3", FMOD_DEFAULT, 0, &valikko);
    FMOD_System_CreateSound(system, "media/sounds/aani4.mp3", FMOD_DEFAULT, 0, &alku);

    if (conffi.aanet) {
        FMOD_Channel_Stop(channel);
        FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, alku, false, &channel); //Ja soitetaan se
    }


    if (conffi.musiikki) {
        FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, musiikki_valikko, false, &channel_musiikki_valikko); //Ja soitetaan se
        FMOD_Channel_SetVolume(channel_musiikki_valikko, 1);
    }
    ///////////////////////////////////////////////////////////////////////

    while (!pois) {
        //Näppäintarkistukset
        while (SDL_PollEvent(&tapahtuma)) {      // niin kauan kun on tapahtumia käsittelemättä
            switch( tapahtuma.type ){            // tapahtuman tyyppi
                case SDL_QUIT:
                    pois = true;
                case SDL_KEYUP:          // näppäin noussut
                    break;
                case SDL_KEYDOWN:
                    switch (tapahtuma.key.keysym.sym) {
                        case SDLK_ESCAPE:
                            if (valikko_syvyys == 0)
                                pois = true;
                            else {
                                valikko_syvyys = 0;
                            }
                            break;
                        case SDLK_UP:
                            if (valikko_syvyys == 0)
                                paavalikko.asetaLisaaValinta(-1);

                            if (valikko_syvyys == 2)
                                asetusvalikko.asetaLisaaValinta(-1);

                            if (conffi.aanet) {
                                FMOD_Channel_Stop(channel);
                                FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, valikko, false, &channel); //Ja soitetaan se
                            }
                            break;
                        case SDLK_DOWN:
                            if (valikko_syvyys == 0)
                                paavalikko.asetaLisaaValinta(+1);

                            if (valikko_syvyys == 2)
                                asetusvalikko.asetaLisaaValinta(+1);

                            if (conffi.aanet) {
                                FMOD_Channel_Stop(channel);
                                FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, valikko, false, &channel); //Ja soitetaan se
                            }
                            break;
                        case SDLK_SPACE:
                        case SDLK_RETURN:
                            switch (valikko_syvyys) {
                                case 0:
                                    switch (paavalikko.haeValinta()) {
                                        case 0:
                                            pois = true;
                                            peliin = true;
                                            break;
                                        case 1:
                                            valikko_syvyys = 2;
                                            break;
                                        case 2:
                                            valikko_syvyys = 3;
                                            break;
                                        case 3:
                                            pois = true;
                                            break;
                                    }
                                    break;
                                case 2:
                                    if (asetusvalikko.haeValinta() < 3) {
                                        asetusvalikko.vaihdaTosi(asetusvalikko.haeValinta());
                                    }

                                    if (asetusvalikko.haeValinta() == 3) {
                                        valikko_syvyys = 0;
                                    }

                                    if (asetusvalikko.haeValinta() == 4) {
                                        config_file asetukset("asetukset.conf");

                                        asetukset.tallenna("musiikki", asetusvalikko.haeArvo(0));
                                        asetukset.tallenna("aanet", asetusvalikko.haeArvo(1));
                                        asetukset.tallenna("kokoruututila", asetusvalikko.haeArvo(2));

                                        asetukset.tallenna_tiedostoon( "asetukset.conf" );

                                        valikko_syvyys = 0;
                                    }

                                    break;
                                case 3:
                                    //Tehnyt valikko
                                    break;
                            }
                    }
                    break;
            }
        }

        if (valikko_syvyys == 0)
            PiirraKuva(buf, naytto, 0, 0);


        if (valikko_syvyys == 2) {
            PiirraKuva(buf3, naytto, 0, 0);
            asetusvalikko.piirraPinta(naytto); //Päävalikko piirretään aina
        }

        if (valikko_syvyys == 3) {
            PiirraKuva(buf2, naytto, 0, 0);
            //tehnytvalikko.piirraPinta(naytto); //Päävalikko piirretään aina
        }

        paavalikko.piirraPinta(naytto); //Päävalikko piirretään aina

        SDL_Flip(naytto);
    }

    FMOD_Sound_Release(valikko);

    //Vapautetaan pinnat
    SDL_FreeSurface(buf);
    SDL_FreeSurface(buf2);
    SDL_FreeSurface(buf3);

    SDL_FreeSurface(otsikko);
    SDL_FreeSurface(valikko_tausta);
    SDL_FreeSurface(valikko_tausta_2);
    SDL_FreeSurface(peli_nimi);

    SDL_FreeSurface(tekstiPinta);
    SDL_FreeSurface(tekstiPinta2);

    SDL_FreeSurface(tekstiPintaValittu);
    SDL_FreeSurface(tekstiPintaValittu2);

    //Vapautetaan fontti
    TTF_CloseFont(fontti);
    TTF_CloseFont(fontti_sis);
    TTF_CloseFont(nimi);

    FMOD_Channel_Stop(channel_musiikki_valikko);
    FMOD_Sound_Release(musiikki_valikko);

    if (peliin) {
        if (conffi.musiikki) {
            FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, musiikki, false, &channel_musiikki); //Ja soitetaan se
            FMOD_Channel_SetVolume(channel_musiikki, 1);
        }
        peli.lataa(system);
        peli.peliin(naytto, system, conffi.aanet);
    }


    //Suljetaan FMOD
    FMOD_Sound_Release(musiikki);

    FMOD_System_Close(system);

    //Suljetaan SDL
    SDL_FreeSurface(naytto);
    SDL_Quit();
    return 0;
}

int alusta_SDL(SDL_Surface *naytto, asetukset conffi) {
    cout << "Alustetaan SDL:lää..." << endl;
    if( SDL_Init(SDL_INIT_AUDIO|SDL_INIT_VIDEO) < 0 ) { //Alustetaan SDL
        cout << "SDL:n alustus ei onnistunut: " << SDL_GetError() << endl;
        return 1;
    }

    return 0;
};

asetukset haeAsetukset() {
    /////////////////////////////////////////////////////////////////////// Asetusten teko
    config_file conf_tiedosto("asetukset.conf"); //Ladataan config-tiedosto
    asetukset conffi; //Luodaan oma asetusten talteen ottoa varten

    conffi.resox = 1024;//(int)conffi.hae_num(CONFIG_RESOLUUTIO_X); //Haetaan conffitiedostosta resoluutio_leveys-kohta
    conffi.resoy = 768;//(int)conffi.hae_num(CONFIG_RESOLUUTIO_Y); // -||- resoluutio_korkeus-kohta

    /////////////////////////////////////////////////////////////////////// Asetusten haku
    //Ei mennä raja-arvojen yli
    if (conffi.resox > 1024)
        conffi.resox = 1024;

    if (conffi.resoy > 768)
        conffi.resoy = 768;

    //Haetaan musiikki-muuttuja
    if ((int)conf_tiedosto.hae_num(CONFIG_MUSIIKKI) > 0 ) //Onko suurempi kuin 0, jos on niin asetetaan true:ksi musiikki
        conffi.musiikki = true;
    else
        conffi.musiikki = false;

    //Haetaan aanet-muuttuja
    if ((int)conf_tiedosto.hae_num(CONFIG_AANET) > 0 ) //Onko suurempi kuin 0, jos on niin asetetaan true:ksi musiikki
        conffi.aanet = true;
    else
        conffi.aanet = false;

    if ((int)conf_tiedosto.hae_num(CONFIG_KOKORUUTU) > 0 ) //Onko suurempi kuin 0, jos on niin asetetaan true:ksi musiikki
        conffi.kokoruututila = true;
    else
        conffi.kokoruututila = false;

    conffi.kieli = conf_tiedosto.hae_str(CONFIG_KIELI);

    conf_tiedosto.poista_kaikki(); //Poistetaan lopuksi turhaa muistia viemästä
    return conffi;
}

void PiirraKuva(SDL_Surface *kuva, SDL_Surface *naytto, int x, int y) {
  SDL_Rect alue; // mille alueellä näyttöä kuva piirretään
  alue.x = x; // koordinaatit
  alue.y = y;
  SDL_BlitSurface(kuva, NULL, naytto, &alue); // piirto
}

TTF_Font* LoadFont(char *filename, int ptsize) {  //Fontin latausfunktio [tiedostonimi, fonttikoko]
    TTF_Font* temppi; //Väliaikainen muuttuja
    temppi = TTF_OpenFont(filename, ptsize);  //Ladataan fontti
    if (temppi == NULL) {
        cout << "Fontti ei voitu ladata:" << TTF_GetError() << endl;
        //Fontin lataaminen ei onnistunut. std::cout on kommentoitu pois koska tässä projektissa en sitä käytä, mutta olkoon esimerkkinä.
        //Lisää tähän haluamasi virheilmoitus!
    }
    return temppi; //Palautetaan fontti
}

void blitText(TTF_Font *fontti, SDL_Surface **destSurf, SDL_Color fgColor, SDL_Color bgColor, char teksti[], textquality quality) {

    //tutkitaan piirtotapa ja piirretään sen mukaisesti
    if (quality == solid) {
        *destSurf = TTF_RenderText_Solid(fontti, teksti, fgColor);
    } else if (quality == shaded) {
        *destSurf = TTF_RenderText_Shaded(fontti, teksti, fgColor, bgColor);
    } else if (quality == blended) {
        *destSurf = TTF_RenderText_Blended(fontti, teksti, fgColor);
    }
}
