#include "kartta.h"

#include <SDL_image.h>
#include <iostream>
#include <fstream>

using namespace std;

void Kartta::lataaKuvat() {
    palat[0] = IMG_Load("media/images/palikka_alku_alku.png");
    palat[1] = IMG_Load("media/images/palikka_alku_normaali.png");
    palat[2] = IMG_Load("media/images/palikka_alku_loppu.png");

    palat[3] = IMG_Load("media/images/palikka_alku.png");
    palat[4] = IMG_Load("media/images/palikka_normaali.png");
    palat[5] = IMG_Load("media/images/palikka_loppu.png");

    palat[6] = IMG_Load("media/images/palikka_loppu_alku.png");
    palat[7] = IMG_Load("media/images/palikka_loppu_normaali.png");
    palat[8] = IMG_Load("media/images/palikka_loppu_loppu.png");

    tausta = IMG_Load("media/images/kentta_tausta.png");

    koko = 32;
    vier_x = 0;
    vier_y = 0;
}
bool Kartta::tarkistaTormays(int x, int y) {
    kentta_iter = kentta.begin();

    while (kentta_iter != kentta.end()) {
        //cout << "Torm.tarkistus: " << (*kentta_iter).x << " == " << x << " and " << (*kentta_iter).y << " == " << y << endl;
        if ((*kentta_iter).x == x and (*kentta_iter).y == y) {
            return true;
        }

        kentta_iter++;
    }

    return false;
}

int Kartta::haeRuudunkoko() {
    return koko;
}

void Kartta::lataaKartta(string file) {
    string s;
    ifstream fi;

    fi.open(file.c_str(), ios::in);

    int x;
    int y;
    int k;

    bool solid;

    int act;

    while (fi.peek() != EOF) {
        pala uusi;

        fi.read((char *)&(x), sizeof(int));
        fi.read((char *)&(y), sizeof(int));

        fi.read((char *)&(k), sizeof(int));

        fi.read((char *)&(solid), sizeof(bool));
        fi.read((char *)&(act), sizeof(int));

        uusi.x = x;
        uusi.y = y;
        uusi.k = k;
        uusi.act = act;
        uusi.solid = solid;

        kentta.push_back(uusi);
    }
    fi.close();

    Uint32 rmask, gmask, bmask, amask;

    lev = haeLeveys();
    kor = haeKorkeus();

    /* SDL interprets each pixel as a 32-bit number, so our masks must depend
       on the endianness (byte order) of the machine */
#if SDL_BYTEORDER == SDL_BIG_ENDIAN
    rmask = 0xff000000;
    gmask = 0x00ff0000;
    bmask = 0x0000ff00;
    amask = 0x000000ff;
#else
    rmask = 0x000000ff;
    gmask = 0x0000ff00;
    bmask = 0x00ff0000;
    amask = 0xff000000;
#endif

    kartta = SDL_CreateRGBSurface(SDL_HWSURFACE, (lev*32)+32, (kor*32)+32, 32,
                                   rmask, gmask, bmask, amask);

    aika_kent.alustaAika();
}

void Kartta::tallennaKartta(string filename) {
    ofstream fi;

    fi.open(filename.c_str());

    kentta_iter = kentta.begin();

    while (kentta_iter != kentta.end()) {

        fi.write((char *)&((*kentta_iter).x), sizeof(int));
        fi.write((char *)&((*kentta_iter).y), sizeof(int));

        fi.write((char *)&((*kentta_iter).k), sizeof(int));

        fi.write((char *)&((*kentta_iter).solid), sizeof(bool));
        fi.write((char *)&((*kentta_iter).act), sizeof(int));

        kentta_iter++;
    }

    fi.close();
}

void Kartta::piirraKentta() {
    //Taustan piirto
    for (int i = 0; i <= kor; i++) {
        for (int a = 0; a <= lev; a++) {
            piirraPalanen(tausta, kartta, a*512, i*512);
        }
    }

    kentta_iter = kentta.begin();

    while (kentta_iter != kentta.end()) {
        piirraPalanen(palat[((*kentta_iter).k)], kartta, ((*kentta_iter).x)*koko, ((*kentta_iter).y)*koko);
        kentta_iter++;
    }
}

SDL_Surface *Kartta::piirraPalanen(SDL_Surface *palanen, SDL_Surface *naytto, int x, int y) {
    SDL_Rect alue; // mille alueellä näyttöä kuva piirretään
    alue.x = x; // koordinaatit
    alue.y = y;
    SDL_BlitSurface(palanen, NULL, naytto, &alue); // piirto
}

int Kartta::haeVier_X() {
    return vier_x;
}

int Kartta::haeVier_Y() {
    return vier_y;
}

void Kartta::rajoita_Vier() {
    //LEVEYS
    if(vier_x < 0)
		vier_x = 0;

	else if(vier_x+1024 > (lev+1)*koko)
		vier_x = (lev+1)*koko - 1024;

    //KORKEUS
	if(vier_y < 0)
		vier_y = 0;

	else if(vier_y + 768 > (kor+1)*koko)
		vier_y = (kor+1)*koko - 768;
}

void Kartta::vier(int x, int y) {
    vier_x = x;
    vier_y = y;
}

void Kartta::piirraKartta(SDL_Surface *naytto) {
    piirraPalanen(kartta, naytto, -vier_x, -vier_y);
}

void Kartta::luoNelio(int alkux, int alkuy, int leveys, int korkeus) {
    pala uusi;

    uusi.x = alkux;
    uusi.y = alkuy;

    uusi.solid = true;
    uusi.k = 0;

    kentta.push_back(uusi);

    uusi.k = 1;

    for (int i = 0; i <= leveys; i++) {
        uusi.x++;
        kentta.push_back(uusi);
    }

    uusi.k = 2;
    uusi.x++;

    kentta.push_back(uusi);

    ///////////////////////////////
    for (int i = 0; i <= korkeus; i++) {
        uusi.y++;
        uusi.x = alkux;
        uusi.k = 3;

        kentta.push_back(uusi);

        uusi.k = 4;

        for (int i = 0; i <= leveys; i++) {
            uusi.x++;
            kentta.push_back(uusi);
        }

        uusi.k = 5;
        uusi.x++;

        kentta.push_back(uusi);
    }

    //////////////////////////////
    uusi.y++;
    uusi.x = alkux;
    uusi.k = 6;

    kentta.push_back(uusi);

    uusi.k = 7;

    for (int i = 0; i <= leveys; i++) {
        uusi.x++;
        kentta.push_back(uusi);
    }

    uusi.k = 8;
    uusi.x++;

    kentta.push_back(uusi);

}

int Kartta::haeAlkuP_X() {
    kentta_iter = kentta.begin();

    while (kentta_iter != kentta.end()) {
        //cout << "Torm.tarkistus: " << (*kentta_iter).x << " == " << x << " and " << (*kentta_iter).y << " == " << y << endl;
        if ((*kentta_iter).act == 1) {
            return (*kentta_iter).x;
        }

        kentta_iter++;
    }

    return false;
};

int Kartta::haeAlkuP_Y() {
        kentta_iter = kentta.begin();

    while (kentta_iter != kentta.end()) {
        if ((*kentta_iter).act == 1) {
            return (*kentta_iter).y;
        }

        kentta_iter++;
    }

    return 0;
};

int Kartta::haeKorkeus() {
    kentta_iter = kentta.begin();

    int korkeus = 0;

    while (kentta_iter != kentta.end()) {
        if ((*kentta_iter).y > korkeus)
            korkeus = (*kentta_iter).y;
        kentta_iter++;
    }

    return korkeus;
}

int Kartta::haeLeveys() {
    kentta_iter = kentta.begin();

    int leveys = 0;

    while (kentta_iter != kentta.end()) {
        if ((*kentta_iter).x > leveys)
            leveys = (*kentta_iter).x;
        kentta_iter++;
    }

    return leveys;
}

void Kartta::poistaKaikkiPalikkat() {
    kentta.erase(kentta.begin(), kentta.end());
}

minsec Kartta::haeAika() {
    return aika_kent.haeAika();
}
