#include "ukko.h"

#include <SDL_image.h>
#include <iostream>

using namespace std;

#include "../common/common.h"

void Ukko::ajattele(Kartta kartta, FMOD_SYSTEM *system, bool aanet) {
    kartta.vier(x,y);
    nopeusx = 0;

    nappi = SDL_GetKeyState(NULL);
    if ( nappi[ SDLK_LEFT ] ) {
        nopeusx = -UKKO_LIIKKUMISVOIMA;
        katsoO = false;
    }
    if ( nappi[ SDLK_RIGHT ] ) {
        nopeusx = UKKO_LIIKKUMISVOIMA;
        katsoO = true;
    }
    if ( nappi[ SDLK_LSHIFT ] and maassa == true ) {
        nopeusy = -UKKO_HYPPYVOIMA;
        maassa = false;

        if (aanet) {
            FMOD_Channel_Stop(kannu);
            FMOD_System_PlaySound(system, FMOD_CHANNEL_FREE, hyppy, false, &kannu); //Ja soitetaan se
            FMOD_Channel_SetVolume(kannu, 0.4);
        }
    }

    int tilekoord;

    //X-suunta ensin
    if (nopeusx > 0) {
        //Oikealle
        if(tormays_pysty(x + nopeusx + l, y, tilekoord, kartta)) {
            x = tilekoord * kartta.haeRuudunkoko() - l -1;
        } else {
            x += nopeusx;
        }
    } else if (nopeusx < 0) {
        //vasemmalle
        if(tormays_pysty(x + nopeusx, y, tilekoord, kartta))
            x = (tilekoord+1) * kartta.haeRuudunkoko() +1;
        else
            x += nopeusx;
    }

    //Sitten Y
    if (nopeusy < 0) { //Jos mennään ylöpäin
        if (tormays_vaaka(x, y + nopeusy, tilekoord, kartta)) { //tarkistetaan törmäys, jos törmätään
            y = (tilekoord+1) * kartta.haeRuudunkoko() +1;
            nopeusy = 0;
        } else {
            y += nopeusy;
            nopeusy += UKKO_GRAVITAATIO;
        }
    } else { //Jos alaspäin
        if (tormays_vaaka(x, y + nopeusy + k, tilekoord, kartta)) { //tarkistetaan törmäys
            y = tilekoord * kartta.haeRuudunkoko() - k -1;
			nopeusy = 1;

			if(!nappi[SDLK_LSHIFT])
				maassa = true;
        } else { //Jos ollaan ilmassa
            y += nopeusy;
			nopeusy += UKKO_GRAVITAATIO;

			if(nopeusy >= kartta.haeRuudunkoko())
				nopeusy = kartta.haeRuudunkoko();

			maassa = false;
        }
    }

	//kartta.vier(y - 382, x - 512);

	//kartta.rajoita_Vier();
}


bool Ukko::tormays_pysty(int x, int y,int &tilekoordx, Kartta kartta) {
    int palikkapiks = y-(y%kartta.haeRuudunkoko());
	int testattu = y + k;

	tilekoordx = x / kartta.haeRuudunkoko();
	int tilekoordy = palikkapiks / kartta.haeRuudunkoko();

	while(palikkapiks <= testattu){
		if(kartta.tarkistaTormays(tilekoordx, tilekoordy)) {
			return true;
		}

		tilekoordy++;
		palikkapiks += kartta.haeRuudunkoko();
	}

	return false;
}

bool Ukko::tormays_vaaka(int x, int y,int &tilekoordy, Kartta kartta) {

	int tilexpixels = x-(x % kartta.haeRuudunkoko());
	int testend = x + l;

	tilekoordy = y / kartta.haeRuudunkoko();
	int tilecoordx = tilexpixels / kartta.haeRuudunkoko();

	while(tilexpixels <= testend){
		if(kartta.tarkistaTormays(tilecoordx, tilekoordy))
			return true;

		tilecoordx++;
		tilexpixels += kartta.haeRuudunkoko();
	}

	return false;
}

void Ukko::piirra(SDL_Surface *naytto, Kartta kentta) {
    SDL_Rect alue; // mille alueellä näyttöä kuva piirretään
    alue.x = x - kentta.haeVier_X(); // koordinaatit
    alue.y = y - kentta.haeVier_Y();

    if (maassa == true) {
        if (katsoO == true) {
            SDL_SetColorKey(hahmo, SDL_SRCCOLORKEY, SDL_MapRGB(hahmo->format,255,255,255));
            SDL_BlitSurface(hahmo, NULL, naytto, &alue); // piirto
        } else {
            SDL_SetColorKey(hahmov, SDL_SRCCOLORKEY, SDL_MapRGB(hahmo->format,255,255,255));
            SDL_BlitSurface(hahmov, NULL, naytto, &alue); // piirto
        }
    } else {
        if (katsoO == true) {
            SDL_SetColorKey(hahmohyppy, SDL_SRCCOLORKEY, SDL_MapRGB(hahmo->format,255,255,255));
            SDL_BlitSurface(hahmohyppy, NULL, naytto, &alue); // piirto
        } else {
            SDL_SetColorKey(hahmohyppyv, SDL_SRCCOLORKEY, SDL_MapRGB(hahmo->format,255,255,255));
            SDL_BlitSurface(hahmohyppyv, NULL, naytto, &alue); // piirto
        }
    }

    //kentta.vier(kentta.haeVier_X(), 0);
}

void Ukko::lataa(FMOD_SYSTEM *system) {
    hahmo = IMG_Load("media/images/peli_hahmo.png");
    hahmov = IMG_Load("media/images/peli_hahmov.png");

    hahmohyppy = IMG_Load("media/images/peli_hahmohyppy.png");
    hahmohyppyv = IMG_Load("media/images/peli_hahmohyppyv.png");

    x = 3*32;
    y = 30*32;
    k = 100;
    l = 83;
    nopeusx = 0;
    nopeusy = 0;

    FMOD_System_CreateSound(system, "media/sounds/aani1.mp3", FMOD_DEFAULT, 0, &hyppy);
}

int Ukko::haeX() {
    return x;
}

int Ukko::haeY() {
    return y;
}

void Ukko::asetaPaikka(int x, int y) {
    this->x = x;
    this->y = y;
}
